==> gpt_prompt-0.0.7.tar.gz: gpt_prompt-0.0.7/README.md <==
# <p align="center">GPT-prompt</p>
<p align="center"><i>集成所有好用的提问</i></p>
<p align="center"><i>Integrate all useful questions</i></p>

<p align="center">
<a href="https://github.com/limaoyi1/GPT-prompt/fork" target="blank">
<img src="https://img.shields.io/github/forks/limaoyi1/GPT-prompt?style=for-the-badge" alt="Auto_PPT forks"/>
</a>

<a href="https://github.com/limaoyi1/GPT-prompt/stargazers" target="blank">
<img src="https://img.shields.io/github/stars/limaoyi1/GPT-prompt?style=for-the-badge" alt="Auto_PPT stars"/>
</a>
<a href="https://github.com/limaoyi1/GPT-prompt/pulls" target="blank">
<img src="https://img.shields.io/github/issues-pr/limaoyi1/GPT-prompt?style=for-the-badge" alt="Auto_PPT pull-requests"/>
</a>
<a href='https://github.com/limaoyi1/GPT-prompt/blob/main/LICENSE'>
<img src='https://img.shields.io/github/license/limaoyi1/GPT-prompt?&label=Latest&style=for-the-badge' alt="Auto_PPT LICENSE">
</a>
<a href='https://github.com/limaoyi1/GPT-prompt/releases'>
<img src='https://img.shields.io/github/release/limaoyi1/GPT-prompt?&label=Latest&style=for-the-badge' alt="Auto_PPT releases">
</a>
</p>

## 我想要做什么?
>这个库的目标是集成所有通用的GPT提问,让提问可以不用再让程序员们痛苦.
让通用提问库作为所有AI框架的第一选择.这很酷是不是?

## What do I want to do?

>The goal of this library is to integrate all common GPT questions, so that questions can no longer cause programmers pain
>Make the universal question library the first choice for all AI frameworks. Isn't that cool?

## 使用方法
```bash
pip install gpt_prompt
```
> 或者
```bash
pip install -i https://pypi.org/simple/ gpt_prompt
```

## Usage Instructions
```bash
pip install gpt_prompt
```
> Alternatively,
```bash
pip install -i https://pypi.org/simple/ gpt_prompt
```


## 欢迎大家随时反馈和提交
>众人拾柴火焰高

## Welcome everyone to provide feedback and submit at any time
> Alone we can do so little; together we can do so much

## 🌟 Star History

<br>

[![Star History Chart](https://api.star-history.com/svg?repos=limaoyi1/GPT-prompt&type=Timeline)](https://star-history.com/#limaoyi1/GPT-prompt&Timeline)

</br>

==> gpt_prompt-0.0.11.tar.gz: gpt_prompt-0.0.11/README.md <==
# <p align="center">GPT-prompt</p>
<p align="center"><i>集成所有好用的提问</i></p>
<p align="center"><i>Integrate all useful questions</i></p>

<p align="center">
<a href="https://github.com/limaoyi1/GPT-prompt/fork" target="blank">
<img src="https://img.shields.io/github/forks/limaoyi1/GPT-prompt?style=for-the-badge" alt="Auto_PPT forks"/>
</a>

<a href="https://github.com/limaoyi1/GPT-prompt/stargazers" target="blank">
<img src="https://img.shields.io/github/stars/limaoyi1/GPT-prompt?style=for-the-badge" alt="Auto_PPT stars"/>
</a>
<a href="https://github.com/limaoyi1/GPT-prompt/pulls" target="blank">
<img src="https://img.shields.io/github/issues-pr/limaoyi1/GPT-prompt?style=for-the-badge" alt="Auto_PPT pull-requests"/>
</a>
<a href='https://github.com/limaoyi1/GPT-prompt/blob/main/LICENSE'>
<img src='https://img.shields.io/github/license/limaoyi1/GPT-prompt?&label=Latest&style=for-the-badge' alt="Auto_PPT LICENSE">
</a>
<a href='https://github.com/limaoyi1/GPT-prompt/releases'>
<img src='https://img.shields.io/github/release/limaoyi1/GPT-prompt?&label=Latest&style=for-the-badge' alt="Auto_PPT releases">
</a>
</p>

## 我想要做什么?
>这个库的目标是集成所有通用的GPT提问,让提问可以不用再让程序员们痛苦.
让通用提问库作为所有AI框架的第一选择.这很酷是不是?

## What do I want to do?

>The goal of this library is to integrate all common GPT questions, so that questions can no longer cause programmers pain
>Make the universal question library the first choice for all AI frameworks. Isn't that cool?

## 安装方法
```bash
pip install gpt-prompt
```
> 或者
```bash
pip install -i https://pypi.org/simple/ gpt-prompt
```

## Install Instructions
```bash
pip install gpt-prompt
```
> Alternatively,
```bash
pip install -i https://pypi.org/simple/ gpt-prompt
```
## 使用方法
```python
from gpt_prompt.character.advertiser import AdvertiserPrompt

if __name__ == '__main__':
    build = AdvertiserPrompt().build(language="en")
    print(build)
```

## Usage Instructions
```python
from gpt_prompt.character.advertiser import AdvertiserPrompt

if __name__ == '__main__':
    build = AdvertiserPrompt().build(language="en")
    print(build)
```



## 欢迎大家随时反馈和提交
>众人拾柴火焰高

## Welcome everyone to provide feedback and submit at any time
> Alone we can do so little; together we can do so much

## 🌟 Star History

[![Star History Chart](https://api.star-history.com/svg?repos=limaoyi1/GPT-prompt&type=Timeline)](https://star-history.com/#limaoyi1/GPT-prompt&Timeline)
